Struct imgui_sys::ImDrawCornerFlags [−]
#[repr(C)]pub struct ImDrawCornerFlags { /* fields omitted */ }
Flags for indictating which corner of a rectangle should be rounded
Methods
impl ImDrawCornerFlags
impl ImDrawCornerFlagspub const TopLeft: ImDrawCornerFlags
TopLeft: ImDrawCornerFlags = ImDrawCornerFlags{bits: 1 << 0,}
pub const TopRight: ImDrawCornerFlags
TopRight: ImDrawCornerFlags = ImDrawCornerFlags{bits: 1 << 1,}
pub const BotLeft: ImDrawCornerFlags
BotLeft: ImDrawCornerFlags = ImDrawCornerFlags{bits: 1 << 2,}
pub const BotRight: ImDrawCornerFlags
BotRight: ImDrawCornerFlags = ImDrawCornerFlags{bits: 1 << 3,}
pub const Top: ImDrawCornerFlags
Top: ImDrawCornerFlags = ImDrawCornerFlags{bits: <ImDrawCornerFlags>::TopLeft.bits | <ImDrawCornerFlags>::TopRight.bits,}
pub const Bot: ImDrawCornerFlags
Bot: ImDrawCornerFlags = ImDrawCornerFlags{bits: <ImDrawCornerFlags>::BotLeft.bits | <ImDrawCornerFlags>::BotRight.bits,}
pub const Left: ImDrawCornerFlags
Left: ImDrawCornerFlags = ImDrawCornerFlags{bits: <ImDrawCornerFlags>::TopLeft.bits | <ImDrawCornerFlags>::BotLeft.bits,}
pub const Right: ImDrawCornerFlags
Right: ImDrawCornerFlags = ImDrawCornerFlags{bits: <ImDrawCornerFlags>::TopRight.bits | <ImDrawCornerFlags>::BotRight.bits,}
pub const All: ImDrawCornerFlags
All: ImDrawCornerFlags = ImDrawCornerFlags{bits: 15,}
pub fn empty() -> ImDrawCornerFlags
pub fn empty() -> ImDrawCornerFlagsReturns an empty set of flags.
pub fn all() -> ImDrawCornerFlags
pub fn all() -> ImDrawCornerFlagsReturns the set containing all flags.
pub fn bits(&self) -> c_int
pub fn bits(&self) -> c_intReturns the raw value of the flags currently stored.
pub fn from_bits(bits: c_int) -> Option<ImDrawCornerFlags>
pub fn from_bits(bits: c_int) -> Option<ImDrawCornerFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: c_int) -> ImDrawCornerFlags
pub fn from_bits_truncate(bits: c_int) -> ImDrawCornerFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: ImDrawCornerFlags) -> bool
pub fn intersects(&self, other: ImDrawCornerFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: ImDrawCornerFlags) -> bool
pub fn contains(&self, other: ImDrawCornerFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: ImDrawCornerFlags)
pub fn insert(&mut self, other: ImDrawCornerFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: ImDrawCornerFlags)
pub fn remove(&mut self, other: ImDrawCornerFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: ImDrawCornerFlags)
pub fn toggle(&mut self, other: ImDrawCornerFlags)Toggles the specified flags in-place.
pub fn set(&mut self, other: ImDrawCornerFlags, value: bool)
pub fn set(&mut self, other: ImDrawCornerFlags, value: bool)Inserts or removes the specified flags depending on the passed value.