Struct imgui_sys::ImDrawListFlags [−]
#[repr(C)]pub struct ImDrawListFlags { /* fields omitted */ }
Methods
impl ImDrawListFlags
impl ImDrawListFlagspub const AntiAliasedLines: ImDrawListFlags
AntiAliasedLines: ImDrawListFlags = ImDrawListFlags{bits: 1 << 0,}
pub const AntiAliasedFill: ImDrawListFlags
AntiAliasedFill: ImDrawListFlags = ImDrawListFlags{bits: 1 << 1,}
pub fn empty() -> ImDrawListFlags
pub fn empty() -> ImDrawListFlagsReturns an empty set of flags.
pub fn all() -> ImDrawListFlags
pub fn all() -> ImDrawListFlagsReturns the set containing all flags.
pub fn bits(&self) -> c_int
pub fn bits(&self) -> c_intReturns the raw value of the flags currently stored.
pub fn from_bits(bits: c_int) -> Option<ImDrawListFlags>
pub fn from_bits(bits: c_int) -> Option<ImDrawListFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: c_int) -> ImDrawListFlags
pub fn from_bits_truncate(bits: c_int) -> ImDrawListFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: ImDrawListFlags) -> bool
pub fn intersects(&self, other: ImDrawListFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: ImDrawListFlags) -> bool
pub fn contains(&self, other: ImDrawListFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: ImDrawListFlags)
pub fn insert(&mut self, other: ImDrawListFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: ImDrawListFlags)
pub fn remove(&mut self, other: ImDrawListFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: ImDrawListFlags)
pub fn toggle(&mut self, other: ImDrawListFlags)Toggles the specified flags in-place.
pub fn set(&mut self, other: ImDrawListFlags, value: bool)
pub fn set(&mut self, other: ImDrawListFlags, value: bool)Inserts or removes the specified flags depending on the passed value.