Struct imgui_sys::ImGuiColorEditFlags [−]
#[repr(C)]pub struct ImGuiColorEditFlags { /* fields omitted */ }
Color edit flags
Methods
impl ImGuiColorEditFlags
impl ImGuiColorEditFlagspub const NoAlpha: ImGuiColorEditFlags
NoAlpha: ImGuiColorEditFlags = ImGuiColorEditFlags{bits: 1 << 1,}
pub const NoPicker: ImGuiColorEditFlags
NoPicker: ImGuiColorEditFlags = ImGuiColorEditFlags{bits: 1 << 2,}
pub const NoOptions: ImGuiColorEditFlags
NoOptions: ImGuiColorEditFlags = ImGuiColorEditFlags{bits: 1 << 3,}
pub const NoSmallPreview: ImGuiColorEditFlags
NoSmallPreview: ImGuiColorEditFlags = ImGuiColorEditFlags{bits: 1 << 4,}
pub const NoInputs: ImGuiColorEditFlags
NoInputs: ImGuiColorEditFlags = ImGuiColorEditFlags{bits: 1 << 5,}
pub const NoTooltip: ImGuiColorEditFlags
NoTooltip: ImGuiColorEditFlags = ImGuiColorEditFlags{bits: 1 << 6,}
pub const NoLabel: ImGuiColorEditFlags
NoLabel: ImGuiColorEditFlags = ImGuiColorEditFlags{bits: 1 << 7,}
pub const NoSidePreview: ImGuiColorEditFlags
NoSidePreview: ImGuiColorEditFlags = ImGuiColorEditFlags{bits: 1 << 8,}
pub const AlphaBar: ImGuiColorEditFlags
AlphaBar: ImGuiColorEditFlags = ImGuiColorEditFlags{bits: 1 << 9,}
pub const AlphaPreview: ImGuiColorEditFlags
AlphaPreview: ImGuiColorEditFlags = ImGuiColorEditFlags{bits: 1 << 10,}
pub const AlphaPreviewHalf: ImGuiColorEditFlags
AlphaPreviewHalf: ImGuiColorEditFlags = ImGuiColorEditFlags{bits: 1 << 11,}
pub const HDR: ImGuiColorEditFlags
HDR: ImGuiColorEditFlags = ImGuiColorEditFlags{bits: 1 << 12,}
pub const RGB: ImGuiColorEditFlags
RGB: ImGuiColorEditFlags = ImGuiColorEditFlags{bits: 1 << 13,}
pub const HSV: ImGuiColorEditFlags
HSV: ImGuiColorEditFlags = ImGuiColorEditFlags{bits: 1 << 14,}
pub const HEX: ImGuiColorEditFlags
HEX: ImGuiColorEditFlags = ImGuiColorEditFlags{bits: 1 << 15,}
pub const Uint8: ImGuiColorEditFlags
Uint8: ImGuiColorEditFlags = ImGuiColorEditFlags{bits: 1 << 16,}
pub const Float: ImGuiColorEditFlags
Float: ImGuiColorEditFlags = ImGuiColorEditFlags{bits: 1 << 17,}
pub const PickerHueBar: ImGuiColorEditFlags
PickerHueBar: ImGuiColorEditFlags = ImGuiColorEditFlags{bits: 1 << 18,}
pub const PickerHueWheel: ImGuiColorEditFlags
PickerHueWheel: ImGuiColorEditFlags = ImGuiColorEditFlags{bits: 1 << 19,}
pub fn empty() -> ImGuiColorEditFlags
pub fn empty() -> ImGuiColorEditFlagsReturns an empty set of flags.
pub fn all() -> ImGuiColorEditFlags
pub fn all() -> ImGuiColorEditFlagsReturns the set containing all flags.
pub fn bits(&self) -> c_int
pub fn bits(&self) -> c_intReturns the raw value of the flags currently stored.
pub fn from_bits(bits: c_int) -> Option<ImGuiColorEditFlags>
pub fn from_bits(bits: c_int) -> Option<ImGuiColorEditFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: c_int) -> ImGuiColorEditFlags
pub fn from_bits_truncate(bits: c_int) -> ImGuiColorEditFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: ImGuiColorEditFlags) -> bool
pub fn intersects(&self, other: ImGuiColorEditFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: ImGuiColorEditFlags) -> bool
pub fn contains(&self, other: ImGuiColorEditFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: ImGuiColorEditFlags)
pub fn insert(&mut self, other: ImGuiColorEditFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: ImGuiColorEditFlags)
pub fn remove(&mut self, other: ImGuiColorEditFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: ImGuiColorEditFlags)
pub fn toggle(&mut self, other: ImGuiColorEditFlags)Toggles the specified flags in-place.
pub fn set(&mut self, other: ImGuiColorEditFlags, value: bool)
pub fn set(&mut self, other: ImGuiColorEditFlags, value: bool)Inserts or removes the specified flags depending on the passed value.