Struct imgui_sys::ImGuiDragDropFlags [−]
#[repr(C)]pub struct ImGuiDragDropFlags { /* fields omitted */ }
Flags for igBeginDragDropSource(), igAcceptDragDropPayload()
Methods
impl ImGuiDragDropFlags
impl ImGuiDragDropFlagspub const SourceNoPreviewTooltip: ImGuiDragDropFlags
SourceNoPreviewTooltip: ImGuiDragDropFlags = ImGuiDragDropFlags{bits: 1 << 0,}
By default, a successful call to igBeginDragDropSource opens a tooltip so you can display a preview or description of the source contents. This flag disable this behavior.
pub const SourceNoDisableHover: ImGuiDragDropFlags
SourceNoDisableHover: ImGuiDragDropFlags = ImGuiDragDropFlags{bits: 1 << 1,}
By default, when dragging we clear data so that igIsItemHovered() will return true, to avoid subsequent user code submitting tooltips. This flag disable this behavior so you can still call igIsItemHovered() on the source item.
pub const SourceNoHoldToOpenOthers: ImGuiDragDropFlags
SourceNoHoldToOpenOthers: ImGuiDragDropFlags = ImGuiDragDropFlags{bits: 1 << 2,}
Disable the behavior that allows to open tree nodes and collapsing header by holding over them while dragging a source item.
pub const SourceAllowNullID: ImGuiDragDropFlags
SourceAllowNullID: ImGuiDragDropFlags = ImGuiDragDropFlags{bits: 1 << 3,}
Allow items such as igText(), igImage() that have no unique identifier to be used as drag source, by manufacturing a temporary identifier based on their window-relative position. This is extremely unusual within the dear imgui ecosystem and so we made it explicit.
pub const SourceExtern: ImGuiDragDropFlags
SourceExtern: ImGuiDragDropFlags = ImGuiDragDropFlags{bits: 1 << 4,}
External source (from outside of imgui), won't attempt to read current item/window info. Will always return true. Only one Extern source can be active simultaneously.
pub const AcceptBeforeDelivery: ImGuiDragDropFlags
AcceptBeforeDelivery: ImGuiDragDropFlags = ImGuiDragDropFlags{bits: 1 << 10,}
igAcceptDragDropPayload() will returns true even before the mouse button is released. You can then call igIsDelivery() to test if the payload needs to be delivered.
pub const AcceptNoDrawDefaultRect: ImGuiDragDropFlags
AcceptNoDrawDefaultRect: ImGuiDragDropFlags = ImGuiDragDropFlags{bits: 1 << 11,}
Do not draw the default highlight rectangle when hovering over target.
pub const AcceptPeekOnly: ImGuiDragDropFlags
AcceptPeekOnly: ImGuiDragDropFlags = ImGuiDragDropFlags{bits: <ImGuiDragDropFlags>::AcceptBeforeDelivery.bits | <ImGuiDragDropFlags>::AcceptNoDrawDefaultRect.bits,}
For peeking ahead and inspecting the payload before delivery.
pub fn empty() -> ImGuiDragDropFlags
pub fn empty() -> ImGuiDragDropFlagsReturns an empty set of flags.
pub fn all() -> ImGuiDragDropFlags
pub fn all() -> ImGuiDragDropFlagsReturns the set containing all flags.
pub fn bits(&self) -> c_int
pub fn bits(&self) -> c_intReturns the raw value of the flags currently stored.
pub fn from_bits(bits: c_int) -> Option<ImGuiDragDropFlags>
pub fn from_bits(bits: c_int) -> Option<ImGuiDragDropFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: c_int) -> ImGuiDragDropFlags
pub fn from_bits_truncate(bits: c_int) -> ImGuiDragDropFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: ImGuiDragDropFlags) -> bool
pub fn intersects(&self, other: ImGuiDragDropFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: ImGuiDragDropFlags) -> bool
pub fn contains(&self, other: ImGuiDragDropFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: ImGuiDragDropFlags)
pub fn insert(&mut self, other: ImGuiDragDropFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: ImGuiDragDropFlags)
pub fn remove(&mut self, other: ImGuiDragDropFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: ImGuiDragDropFlags)
pub fn toggle(&mut self, other: ImGuiDragDropFlags)Toggles the specified flags in-place.
pub fn set(&mut self, other: ImGuiDragDropFlags, value: bool)
pub fn set(&mut self, other: ImGuiDragDropFlags, value: bool)Inserts or removes the specified flags depending on the passed value.