Struct imgui_sys::ImGuiFocusedFlags [−]
#[repr(C)]pub struct ImGuiFocusedFlags { /* fields omitted */ }
Flags for window focus check
Methods
impl ImGuiFocusedFlags
impl ImGuiFocusedFlagspub const ChildWindows: ImGuiFocusedFlags
ChildWindows: ImGuiFocusedFlags = ImGuiFocusedFlags{bits: 1 << 0,}
pub const RootWindow: ImGuiFocusedFlags
RootWindow: ImGuiFocusedFlags = ImGuiFocusedFlags{bits: 1 << 1,}
pub const RootAndChildWindows: ImGuiFocusedFlags
RootAndChildWindows: ImGuiFocusedFlags = ImGuiFocusedFlags{bits: <ImGuiFocusedFlags>::RootWindow.bits | <ImGuiFocusedFlags>::ChildWindows.bits,}
pub fn empty() -> ImGuiFocusedFlags
pub fn empty() -> ImGuiFocusedFlagsReturns an empty set of flags.
pub fn all() -> ImGuiFocusedFlags
pub fn all() -> ImGuiFocusedFlagsReturns the set containing all flags.
pub fn bits(&self) -> c_int
pub fn bits(&self) -> c_intReturns the raw value of the flags currently stored.
pub fn from_bits(bits: c_int) -> Option<ImGuiFocusedFlags>
pub fn from_bits(bits: c_int) -> Option<ImGuiFocusedFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: c_int) -> ImGuiFocusedFlags
pub fn from_bits_truncate(bits: c_int) -> ImGuiFocusedFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: ImGuiFocusedFlags) -> bool
pub fn intersects(&self, other: ImGuiFocusedFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: ImGuiFocusedFlags) -> bool
pub fn contains(&self, other: ImGuiFocusedFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: ImGuiFocusedFlags)
pub fn insert(&mut self, other: ImGuiFocusedFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: ImGuiFocusedFlags)
pub fn remove(&mut self, other: ImGuiFocusedFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: ImGuiFocusedFlags)
pub fn toggle(&mut self, other: ImGuiFocusedFlags)Toggles the specified flags in-place.
pub fn set(&mut self, other: ImGuiFocusedFlags, value: bool)
pub fn set(&mut self, other: ImGuiFocusedFlags, value: bool)Inserts or removes the specified flags depending on the passed value.