Struct imgui_sys::ImGuiHoveredFlags [−]
#[repr(C)]pub struct ImGuiHoveredFlags { /* fields omitted */ }
Flags for hover checks
Methods
impl ImGuiHoveredFlags
impl ImGuiHoveredFlagspub const ChildWindows: ImGuiHoveredFlags
ChildWindows: ImGuiHoveredFlags = ImGuiHoveredFlags{bits: 1 << 0,}
pub const RootWindow: ImGuiHoveredFlags
RootWindow: ImGuiHoveredFlags = ImGuiHoveredFlags{bits: 1 << 1,}
pub const AllowWhenBlockedByPopup: ImGuiHoveredFlags
AllowWhenBlockedByPopup: ImGuiHoveredFlags = ImGuiHoveredFlags{bits: 1 << 2,}
pub const AllowWhenBlockedByActiveItem: ImGuiHoveredFlags
AllowWhenBlockedByActiveItem: ImGuiHoveredFlags = ImGuiHoveredFlags{bits: 1 << 4,}
pub const AllowWhenOverlapped: ImGuiHoveredFlags
AllowWhenOverlapped: ImGuiHoveredFlags = ImGuiHoveredFlags{bits: 1 << 5,}
pub const RectOnly: ImGuiHoveredFlags
RectOnly: ImGuiHoveredFlags = ImGuiHoveredFlags{bits: <ImGuiHoveredFlags>::AllowWhenBlockedByPopup.bits | <ImGuiHoveredFlags>::AllowWhenBlockedByActiveItem.bits | <ImGuiHoveredFlags>::AllowWhenOverlapped.bits,}
pub const RootAndChildWindows: ImGuiHoveredFlags
RootAndChildWindows: ImGuiHoveredFlags = ImGuiHoveredFlags{bits: <ImGuiFocusedFlags>::RootWindow.bits | <ImGuiFocusedFlags>::ChildWindows.bits,}
pub fn empty() -> ImGuiHoveredFlags
pub fn empty() -> ImGuiHoveredFlagsReturns an empty set of flags.
pub fn all() -> ImGuiHoveredFlags
pub fn all() -> ImGuiHoveredFlagsReturns the set containing all flags.
pub fn bits(&self) -> c_int
pub fn bits(&self) -> c_intReturns the raw value of the flags currently stored.
pub fn from_bits(bits: c_int) -> Option<ImGuiHoveredFlags>
pub fn from_bits(bits: c_int) -> Option<ImGuiHoveredFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: c_int) -> ImGuiHoveredFlags
pub fn from_bits_truncate(bits: c_int) -> ImGuiHoveredFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: ImGuiHoveredFlags) -> bool
pub fn intersects(&self, other: ImGuiHoveredFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: ImGuiHoveredFlags) -> bool
pub fn contains(&self, other: ImGuiHoveredFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: ImGuiHoveredFlags)
pub fn insert(&mut self, other: ImGuiHoveredFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: ImGuiHoveredFlags)
pub fn remove(&mut self, other: ImGuiHoveredFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: ImGuiHoveredFlags)
pub fn toggle(&mut self, other: ImGuiHoveredFlags)Toggles the specified flags in-place.
pub fn set(&mut self, other: ImGuiHoveredFlags, value: bool)
pub fn set(&mut self, other: ImGuiHoveredFlags, value: bool)Inserts or removes the specified flags depending on the passed value.