Struct imgui_sys::ImGuiInputTextFlags [−]
#[repr(C)]pub struct ImGuiInputTextFlags { /* fields omitted */ }
Flags for text inputs
Methods
impl ImGuiInputTextFlags
impl ImGuiInputTextFlagspub const CharsDecimal: ImGuiInputTextFlags
CharsDecimal: ImGuiInputTextFlags = ImGuiInputTextFlags{bits: 1,}
pub const CharsHexadecimal: ImGuiInputTextFlags
CharsHexadecimal: ImGuiInputTextFlags = ImGuiInputTextFlags{bits: 1 << 1,}
pub const CharsUppercase: ImGuiInputTextFlags
CharsUppercase: ImGuiInputTextFlags = ImGuiInputTextFlags{bits: 1 << 2,}
pub const CharsNoBlank: ImGuiInputTextFlags
CharsNoBlank: ImGuiInputTextFlags = ImGuiInputTextFlags{bits: 1 << 3,}
pub const AutoSelectAll: ImGuiInputTextFlags
AutoSelectAll: ImGuiInputTextFlags = ImGuiInputTextFlags{bits: 1 << 4,}
pub const EnterReturnsTrue: ImGuiInputTextFlags
EnterReturnsTrue: ImGuiInputTextFlags = ImGuiInputTextFlags{bits: 1 << 5,}
pub const CallbackCompletion: ImGuiInputTextFlags
CallbackCompletion: ImGuiInputTextFlags = ImGuiInputTextFlags{bits: 1 << 6,}
pub const CallbackHistory: ImGuiInputTextFlags
CallbackHistory: ImGuiInputTextFlags = ImGuiInputTextFlags{bits: 1 << 7,}
pub const CallbackAlways: ImGuiInputTextFlags
CallbackAlways: ImGuiInputTextFlags = ImGuiInputTextFlags{bits: 1 << 8,}
pub const CallbackCharFilter: ImGuiInputTextFlags
CallbackCharFilter: ImGuiInputTextFlags = ImGuiInputTextFlags{bits: 1 << 9,}
pub const AllowTabInput: ImGuiInputTextFlags
AllowTabInput: ImGuiInputTextFlags = ImGuiInputTextFlags{bits: 1 << 10,}
pub const CtrlEnterForNewLine: ImGuiInputTextFlags
CtrlEnterForNewLine: ImGuiInputTextFlags = ImGuiInputTextFlags{bits: 1 << 11,}
pub const NoHorizontalScroll: ImGuiInputTextFlags
NoHorizontalScroll: ImGuiInputTextFlags = ImGuiInputTextFlags{bits: 1 << 12,}
pub const AlwaysInsertMode: ImGuiInputTextFlags
AlwaysInsertMode: ImGuiInputTextFlags = ImGuiInputTextFlags{bits: 1 << 13,}
pub const ReadOnly: ImGuiInputTextFlags
ReadOnly: ImGuiInputTextFlags = ImGuiInputTextFlags{bits: 1 << 14,}
pub const Password: ImGuiInputTextFlags
Password: ImGuiInputTextFlags = ImGuiInputTextFlags{bits: 1 << 15,}
pub const NoUndoRedo: ImGuiInputTextFlags
NoUndoRedo: ImGuiInputTextFlags = ImGuiInputTextFlags{bits: 1 << 16,}
pub fn empty() -> ImGuiInputTextFlags
pub fn empty() -> ImGuiInputTextFlagsReturns an empty set of flags.
pub fn all() -> ImGuiInputTextFlags
pub fn all() -> ImGuiInputTextFlagsReturns the set containing all flags.
pub fn bits(&self) -> c_int
pub fn bits(&self) -> c_intReturns the raw value of the flags currently stored.
pub fn from_bits(bits: c_int) -> Option<ImGuiInputTextFlags>
pub fn from_bits(bits: c_int) -> Option<ImGuiInputTextFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: c_int) -> ImGuiInputTextFlags
pub fn from_bits_truncate(bits: c_int) -> ImGuiInputTextFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: ImGuiInputTextFlags) -> bool
pub fn intersects(&self, other: ImGuiInputTextFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: ImGuiInputTextFlags) -> bool
pub fn contains(&self, other: ImGuiInputTextFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: ImGuiInputTextFlags)
pub fn insert(&mut self, other: ImGuiInputTextFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: ImGuiInputTextFlags)
pub fn remove(&mut self, other: ImGuiInputTextFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: ImGuiInputTextFlags)
pub fn toggle(&mut self, other: ImGuiInputTextFlags)Toggles the specified flags in-place.
pub fn set(&mut self, other: ImGuiInputTextFlags, value: bool)
pub fn set(&mut self, other: ImGuiInputTextFlags, value: bool)Inserts or removes the specified flags depending on the passed value.