Struct imgui_sys::ImGuiSelectableFlags [−]
#[repr(C)]pub struct ImGuiSelectableFlags { /* fields omitted */ }
Flags for selectables
Methods
impl ImGuiSelectableFlags
impl ImGuiSelectableFlagspub const DontClosePopups: ImGuiSelectableFlags
DontClosePopups: ImGuiSelectableFlags = ImGuiSelectableFlags{bits: 1,}
pub const SpanAllColumns: ImGuiSelectableFlags
SpanAllColumns: ImGuiSelectableFlags = ImGuiSelectableFlags{bits: 1 << 1,}
pub const AllowDoubleClick: ImGuiSelectableFlags
AllowDoubleClick: ImGuiSelectableFlags = ImGuiSelectableFlags{bits: 1 << 2,}
pub fn empty() -> ImGuiSelectableFlags
pub fn empty() -> ImGuiSelectableFlagsReturns an empty set of flags.
pub fn all() -> ImGuiSelectableFlags
pub fn all() -> ImGuiSelectableFlagsReturns the set containing all flags.
pub fn bits(&self) -> c_int
pub fn bits(&self) -> c_intReturns the raw value of the flags currently stored.
pub fn from_bits(bits: c_int) -> Option<ImGuiSelectableFlags>
pub fn from_bits(bits: c_int) -> Option<ImGuiSelectableFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: c_int) -> ImGuiSelectableFlags
pub fn from_bits_truncate(bits: c_int) -> ImGuiSelectableFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: ImGuiSelectableFlags) -> bool
pub fn intersects(&self, other: ImGuiSelectableFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: ImGuiSelectableFlags) -> bool
pub fn contains(&self, other: ImGuiSelectableFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: ImGuiSelectableFlags)
pub fn insert(&mut self, other: ImGuiSelectableFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: ImGuiSelectableFlags)
pub fn remove(&mut self, other: ImGuiSelectableFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: ImGuiSelectableFlags)
pub fn toggle(&mut self, other: ImGuiSelectableFlags)Toggles the specified flags in-place.
pub fn set(&mut self, other: ImGuiSelectableFlags, value: bool)
pub fn set(&mut self, other: ImGuiSelectableFlags, value: bool)Inserts or removes the specified flags depending on the passed value.