Struct imgui_sys::ImGuiTreeNodeFlags [−]
#[repr(C)]pub struct ImGuiTreeNodeFlags { /* fields omitted */ }
Flags for trees and collapsing headers
Methods
impl ImGuiTreeNodeFlags
impl ImGuiTreeNodeFlagspub const Selected: ImGuiTreeNodeFlags
Selected: ImGuiTreeNodeFlags = ImGuiTreeNodeFlags{bits: 1,}
pub const Framed: ImGuiTreeNodeFlags
Framed: ImGuiTreeNodeFlags = ImGuiTreeNodeFlags{bits: 1 << 1,}
pub const AllowItemOverlap: ImGuiTreeNodeFlags
AllowItemOverlap: ImGuiTreeNodeFlags = ImGuiTreeNodeFlags{bits: 1 << 2,}
pub const NoTreePushOnOpen: ImGuiTreeNodeFlags
NoTreePushOnOpen: ImGuiTreeNodeFlags = ImGuiTreeNodeFlags{bits: 1 << 3,}
pub const NoAutoOpenOnLog: ImGuiTreeNodeFlags
NoAutoOpenOnLog: ImGuiTreeNodeFlags = ImGuiTreeNodeFlags{bits: 1 << 4,}
pub const DefaultOpen: ImGuiTreeNodeFlags
DefaultOpen: ImGuiTreeNodeFlags = ImGuiTreeNodeFlags{bits: 1 << 5,}
pub const OpenOnDoubleClick: ImGuiTreeNodeFlags
OpenOnDoubleClick: ImGuiTreeNodeFlags = ImGuiTreeNodeFlags{bits: 1 << 6,}
pub const OpenOnArrow: ImGuiTreeNodeFlags
OpenOnArrow: ImGuiTreeNodeFlags = ImGuiTreeNodeFlags{bits: 1 << 7,}
pub const Leaf: ImGuiTreeNodeFlags
Leaf: ImGuiTreeNodeFlags = ImGuiTreeNodeFlags{bits: 1 << 8,}
pub const Bullet: ImGuiTreeNodeFlags
Bullet: ImGuiTreeNodeFlags = ImGuiTreeNodeFlags{bits: 1 << 9,}
pub const FramePadding: ImGuiTreeNodeFlags
FramePadding: ImGuiTreeNodeFlags = ImGuiTreeNodeFlags{bits: 1 << 10,}
pub const CollapsingHeader: ImGuiTreeNodeFlags
CollapsingHeader: ImGuiTreeNodeFlags = ImGuiTreeNodeFlags{bits: <ImGuiTreeNodeFlags>::Framed.bits | <ImGuiTreeNodeFlags>::NoAutoOpenOnLog.bits,}
pub fn empty() -> ImGuiTreeNodeFlags
pub fn empty() -> ImGuiTreeNodeFlagsReturns an empty set of flags.
pub fn all() -> ImGuiTreeNodeFlags
pub fn all() -> ImGuiTreeNodeFlagsReturns the set containing all flags.
pub fn bits(&self) -> c_int
pub fn bits(&self) -> c_intReturns the raw value of the flags currently stored.
pub fn from_bits(bits: c_int) -> Option<ImGuiTreeNodeFlags>
pub fn from_bits(bits: c_int) -> Option<ImGuiTreeNodeFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: c_int) -> ImGuiTreeNodeFlags
pub fn from_bits_truncate(bits: c_int) -> ImGuiTreeNodeFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: ImGuiTreeNodeFlags) -> bool
pub fn intersects(&self, other: ImGuiTreeNodeFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: ImGuiTreeNodeFlags) -> bool
pub fn contains(&self, other: ImGuiTreeNodeFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: ImGuiTreeNodeFlags)
pub fn insert(&mut self, other: ImGuiTreeNodeFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: ImGuiTreeNodeFlags)
pub fn remove(&mut self, other: ImGuiTreeNodeFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: ImGuiTreeNodeFlags)
pub fn toggle(&mut self, other: ImGuiTreeNodeFlags)Toggles the specified flags in-place.
pub fn set(&mut self, other: ImGuiTreeNodeFlags, value: bool)
pub fn set(&mut self, other: ImGuiTreeNodeFlags, value: bool)Inserts or removes the specified flags depending on the passed value.