Crate imgui_sys[−][src]
Structs
| CustomRect | |
| ImColor | |
| ImDrawChannel |
Temporary storage for outputting drawing commands out of order |
| ImDrawCmd |
A single draw command within a parent ImDrawList (generally maps to 1 GPU draw call) |
| ImDrawCornerFlags |
Flags for indictating which corner of a rectangle should be rounded |
| ImDrawData |
All draw command lists required to render the frame |
| ImDrawList |
A single draw command list (generally one per window) |
| ImDrawListFlags | |
| ImDrawListSharedData | |
| ImDrawVert |
A single vertex |
| ImFont |
Runtime data for a single font within a parent ImFontAtlas |
| ImFontAtlas |
Runtime data for multiple fonts, bake multiple fonts into a single texture, TTF/OTF font loader |
| ImFontConfig |
Configuration data when adding a font or merging fonts |
| ImFontGlyph | |
| ImGuiColorEditFlags |
Color edit flags |
| ImGuiComboFlags |
Flags for igBeginCombo |
| ImGuiCond |
Condition flags |
| ImGuiDragDropFlags |
Flags for igBeginDragDropSource(), igAcceptDragDropPayload() |
| ImGuiFocusedFlags |
Flags for window focus check |
| ImGuiHoveredFlags |
Flags for hover checks |
| ImGuiIO |
Main configuration and I/O between your application and ImGui |
| ImGuiInputTextFlags |
Flags for text inputs |
| ImGuiListClipper |
Helper to manually clip large list of items |
| ImGuiPayload |
Data payload for Drag and Drop operations |
| ImGuiSelectableFlags |
Flags for selectables |
| ImGuiSizeConstraintCallbackData | |
| ImGuiStorage | |
| ImGuiStyle |
Runtime data for styling/colors |
| ImGuiTextBuffer | |
| ImGuiTextEditCallbackData | |
| ImGuiTextFilter | |
| ImGuiTreeNodeFlags |
Flags for trees and collapsing headers |
| ImGuiWindowFlags |
Window flags |
| ImVec2 |
A tuple of 2 floating-point values |
| ImVec4 |
A tuple of 4 floating-point values |
| ImVector |
Lightweight vector struct |
| Pair | |
| TextRange |
Enums
| ImGuiCol |
A color identifier for styling |
| ImGuiContext |
ImGui context (opaque) |
| ImGuiKey |
A key identifier (ImGui-side enum) |
| ImGuiMouseCursor |
A mouse cursor identifier |
| ImGuiStyleVar |
A variable identifier for styling |
Constants
| ImGuiCol_COUNT | |
| ImGuiKey_COUNT | |
| ImGuiMouseCursor_COUNT | |
| ImGuiStyleVar_COUNT |
Functions
Type Definitions
| ImDrawCallback | |
| ImDrawIdx |
Vertex index |
| ImGuiID |
Unique ID used by widgets (typically hashed from a stack of string) |
| ImGuiSizeConstraintCallback | |
| ImGuiTextEditCallback | |
| ImTextureID |
User data to identify a texture |
| ImU32 |
32-bit unsigned integer (typically used to store packed colors) |
| ImWchar |
Character for keyboard input/display |
Unions
| PairValue |